@@ -1,5 +1,5 @@
 # FoundationDB Python API
-# Copyright (c) 2013 FoundationDB, LLC
+# Copyright (c) 2012 FoundationDB, LLC
 
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -426,23 +426,29 @@ class Transaction(TransactionRead):
                                               end, len(end))
 
     def clear_range_startswith(self, prefix):
-        if isinstance(prefix, FutureString):
-            prefix = prefix.value
+        prefix = keyToBytes(prefix)
         return self.clear_range(prefix, strinc(prefix))
 
     def watch(self, key):
+        key = keyToBytes(key)
         return FutureVoid(self.capi.fdb_transaction_watch(self.tpointer, key, len(key)))
 
     def add_read_conflict_range(self, begin, end):
+        begin = keyToBytes(begin)
+        end = keyToBytes(end)
         self.capi.fdb_transaction_add_conflict_range(self.tpointer, begin, len(begin), end, len(end), ConflictRangeType.read)
 
     def add_read_conflict_key(self, key):
+        key = keyToBytes(key)
         self.add_read_conflict_range(key, key + b'\x00')
 
     def add_write_conflict_range(self, begin, end):
+        begin = keyToBytes(begin)
+        end = keyToBytes(end)
         self.capi.fdb_transaction_add_conflict_range(self.tpointer, begin, len(begin), end, len(end), ConflictRangeType.write)
 
     def add_write_conflict_key(self, key):
+        key = keyToBytes(key)
         self.add_write_conflict_range(key, key + b'\x00')
 
     def commit(self):
